@@ -376,30 +376,8 @@ class Commands(object):
 
         if answer == 'y':
             ownername, projectname = self.parse_name(args.name)
-
-            copr_url = self.client.config["copr_url"]
-            api_url = "{0}/api".format(copr_url)
-            url = "{0}/coprs/{1}/{2}/{3}/".format(
-                api_url, ownername, projectname, "new_webhook_secret")
-
-            auth = (self.client.config["login"],
-                    self.client.config["token"])
-
-            # @TODO Rewrite this call to the APIv3.
-            # @TODO I am not doing it right away because it is a release-blocker
-            try:
-                response = requests.post(url=url, auth=auth)
-                result = response.json()
-            except requests.ConnectionError as ex:
-                sys.stderr.write(str(ex) + "\n")
-                return
-
-            if result["output"] != "ok":
-                sys.stderr.write(result["error"] + "\n")
-                sys.stderr.write("Un-expected data returned, please report this issue\n")
-                return
-
-            print(result["message"])
+            token = self.client.webhook_proxy.generate(ownername, projectname)
+            print("Generated new token: {0}".format(token.webhook_secret))
 
     @requires_api_auth
     def action_build(self, args):
@@ -567,6 +545,7 @@ class Commands(object):
             multilib=ON_OFF_MAP[args.multilib],
             module_hotfixes=ON_OFF_MAP[args.module_hotfixes],
             fedora_review=args.fedora_review,
+            appstream=ON_OFF_MAP[args.appstream],
         )
         print("New project was successfully created.")
 
@@ -592,6 +571,7 @@ class Commands(object):
             multilib=ON_OFF_MAP[args.multilib],
             module_hotfixes=ON_OFF_MAP[args.module_hotfixes],
             fedora_review=ON_OFF_MAP[args.fedora_review],
+            appstream=ON_OFF_MAP[args.appstream],
         )
 
     @requires_api_auth
@@ -676,26 +656,21 @@ class Commands(object):
 
         """
         username = args.username or self.config["username"]
-        try:
-            projects = self.client.project_proxy.get_list(username)
-            if not projects:
-                sys.stderr.write("No copr retrieved for user: '{0}'\n".format(username))
-                return
+        projects = self.client.project_proxy.get_list(username)
+        if not projects:
+            sys.stderr.write("No copr retrieved for user: '{0}'\n".format(username))
+            return
 
-            for project in projects:
-                print("Name: {0}".format(project.name))
-                print("  Description: {0}".format(project.description))
-                if project.chroot_repos:
-                    print("  Repo(s):")
-                    for name, url in project.chroot_repos.items():
-                        print("    {0}: {1}".format(name, url))
-                if project.additional_repos:
-                    print("  Additional repo: {0}".format(" ".join(project.additional_repos)))
-                print("")
-
-        except CoprRequestException as ex:
-            sys.stderr.write(str(ex) + "\n")
-            sys.stderr.write("Un-expected data returned, please report this issue\n")
+        for project in projects:
+            print("Name: {0}".format(project.name))
+            print("  Description: {0}".format(project.description))
+            if project.chroot_repos:
+                print("  Repo(s):")
+                for name, url in project.chroot_repos.items():
+                    print("    {0}: {1}".format(name, url))
+            if project.additional_repos:
+                print("  Additional repo: {0}".format(" ".join(project.additional_repos)))
+            print("")
 
     def action_status(self, args):
         build = self.client.build_proxy.get(args.build_id)
@@ -959,17 +934,14 @@ class Commands(object):
         ownername, project_dirname = self.parse_name(args.copr_repo)
         projectname = project_dirname.split(':')[0]
         buildopts = buildopts_from_args(args, None)
-        try:
-            build = self.client.package_proxy.build(ownername=ownername, projectname=projectname,
-                                                    packagename=args.name, buildopts=buildopts,
-                                                    project_dirname=project_dirname)
-            print("Build was added to {0}.".format(build.projectname))
-            print("Created builds: {0}".format(build.id))
+        build = self.client.package_proxy.build(ownername=ownername, projectname=projectname,
+                                                packagename=args.name, buildopts=buildopts,
+                                                project_dirname=project_dirname)
+        print("Build was added to {0}.".format(build.projectname))
+        print("Created builds: {0}".format(build.id))
 
-            if not args.nowait:
-                self._watch_builds([build.id])
-        except CoprRequestException as ex:
-            sys.stderr.write(str(ex) + "\n")
+        if not args.nowait:
+            self._watch_builds([build.id])
 
     def action_build_module(self, args):
         """
@@ -1150,6 +1122,11 @@ def setup_parser():
               "discover packaging errors. Failing fedora-review will not fail "
               "the build itself."))
 
+    parser_create.add_argument(
+        "--appstream", choices=["on", "off"], default="on",
+        help=("Generate AppStream metadata for this project. Generating "
+              "metadata slows down the builds in large Copr projects."))
+
     parser_create.set_defaults(func="action_create")
 
     # create the parser for the "modify_project" command
@@ -1203,6 +1180,11 @@ def setup_parser():
               "discover packaging errors. Failing fedora-review will not fail "
               "the build itself."))
 
+    parser_modify.add_argument(
+        "--appstream", choices=["on", "off"], default="on",
+        help=("Generate AppStream metadata for this project. Generating "
+              "metadata slows down the builds in large Copr projects."))
+
     parser_modify.set_defaults(func="action_modify_project")
 
     # create the parser for the "delete" command
